@@ -9,20 +9,21 @@ sentry_hipchat.models
 from django import forms
 
 from sentry.conf import settings
-from sentry.models import ProjectOption
 from sentry.plugins import Plugin, register
 
+import sentry_hipchat
+
 import urllib
 import urllib2
 import json
 import logging
 
-COLORS = dict(
-    ERROR = 'red',
-    WARNING = 'yellow',
-    INFO = 'green',
-    DEBUG = 'purple',
-)   
+COLORS = {
+    'ERROR': 'red',
+    'WARNING': 'yellow',
+    'INFO': 'green',
+    'DEBUG': 'purple',
+}
 
 
 class HipchatOptionsForm(forms.Form):
@@ -37,8 +38,12 @@ class HipchatOptionsForm(forms.Form):
 class HipchatMessage(Plugin):
     author = 'Xavier Ordoquy'
     author_url = 'https://github.com/linovia/sentry-hipchat'
+    version = sentry_hipchat.VERSION
+    description = "Event notification to Hipchat."
+
+    slug = 'hipchat'
     title = 'Hipchat'
-    conf_title = 'Hipchat'
+    conf_title = title
     conf_key = 'hipchat'
     project_conf_form = HipchatOptionsForm
 
@@ -52,20 +57,20 @@ class HipchatMessage(Plugin):
 
         token = self.get_option('token', event.project)
         room = self.get_option('room', event.project)
-        notify = self.get_option('notify', event.project)
-        include_project_name = self.get_option('include_project_name', event.project)
+        notify = self.get_option('notify', event.project) or False
+        include_project_name = self.get_option('include_project_name', event.project) or False
         level = event.get_level_display().upper()
         link = '<a href="%s/%s/group/%d/">(link)</a>' % (settings.URL_PREFIX, group.project.slug, group.id)
 
         if token and room:
             self.send_payload(token, room, '%(site)s[%(server)s]%(project_name)s %(message)s %(link)s' % {
-                'server': event.server_name,
-                'site': ('%s ' % event.site) if event.site else '',
-                'project_name': (' <strong>%s</strong>' % event.project.name) if include_project_name else '',
-                'message': event.message,
-                'link': link,
+                    'server': event.server_name,
+                    'site': ('%s ' % event.site) if event.site else '',
+                    'project_name': (' <strong>%s</strong>' % event.project.name) if include_project_name else '',
+                    'message': event.message,
+                    'link': link,
                 },
-                              notify, color=COLORS.get(level, 'purple'))
+                notify, color=COLORS.get(level, 'purple'))
 
     def send_payload(self, token, room, message, notify, color='red'):
         url = "https://api.hipchat.com/v1/rooms/message"
